/*   This is part of um-ViewOS
 *   The user-mode implementation of OSVIEW -- A Process with a View
 *
 *   umview.h: generic definitions, not directly related to virtualization
 *   
 *   Copyright 2006 Ludovico Gardenghi
 *   
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License, version 2, as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *   $Id: umview.h 668 2009-05-30 15:08:31Z rd235 $
 *
 */

#include <config.h>

#define UMVIEW_NAME PACKAGE_NAME
#define UMVIEW_DESC "umview: The user-mode implementation of View-OS"
#define UMVIEW_VERSION PACKAGE_VERSION

#define UMVIEW_URL "http://view-os.sourceforge.net"

#define UMVIEW_COPYRIGHT "2005-2008 Renzo Davoli, University of Bologna, Italy"
#define UMVIEW_TEAM \
"P. Angelelli, A. Bacchelli, M. Belletti, P. Beverini, L. Bigliardi, D. Billi,\n" \
"A. Forni, L. Gardenghi, A. Gasparini, F. Giunchedi, D. Lacamera, C. Martellini,\n" \
"A. Seraghiti"
